summaryrefslogtreecommitdiffstats
path: root/kgpg/kgpgview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kgpg/kgpgview.h')
-rw-r--r--kgpg/kgpgview.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/kgpg/kgpgview.h b/kgpg/kgpgview.h
index f65323b..9a61988 100644
--- a/kgpg/kgpgview.h
+++ b/kgpg/kgpgview.h
@@ -41,9 +41,10 @@ class TQDragEnterEvent;
class MyEditor : public KTextEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- MyEditor( TQWidget *parent = 0, const char *name = 0);
+ MyEditor( TQWidget *tqparent = 0, const char *name = 0);
private:
TQString message,messages,tempFile;
public slots:
@@ -65,17 +66,18 @@ signals:
};
-class KgpgView : public QWidget
+class KgpgView : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
friend class MyEditor;
public:
/** Constructor for the main view */
- KgpgView(TQWidget *parent = 0, const char *name=0);
+ KgpgView(TQWidget *tqparent = 0, const char *name=0);
/** Destructor for the main view */
~KgpgView();
/** returns a pointer to the document connected to the view instance. Mind that this method requires a KgpgApp instance as a parent
* widget to get to the window document pointer by calling the KgpgApp::getDocument() method.
*
* @see KgpgApp#getDocument
@@ -65,17 +66,18 @@ signals:
/** Destructor for the main view */
~KgpgView();
- /** returns a pointer to the document connected to the view instance. Mind that this method requires a KgpgApp instance as a parent
+ /** returns a pointer to the document connected to the view instance. Mind that this method requires a KgpgApp instance as a tqparent
* widget to get to the window document pointer by calling the KgpgApp::getDocument() method.
*